@@ -141,7 +141,7 @@ The operator precedence is very like Perl's:
 
 =head2 Constants (or binding)
 
-You can define lexical constants with C<constant>, which requires a bare name,
+You can define lexical constants with C<constant>, which requires a bare word,
 and C<my>, which requires a variable name.
 
     : constant FOO = 42;
@@ -181,7 +181,7 @@ C<$~ITERATOR_VAR> is a pseudo object, so you can access its elements
 via the dot-name syntax.
 
     : for $data -> $i {
-        : $~i       # iterator index (0, 1, 2, ...)
+        : $~i       # 0-origin iterator index (0, 1, 2, ...)
         : $~i.index # the same as $~i
         : $~i.count # the same as $~i + 1
 
@@ -329,6 +329,11 @@ Template inclusion is a traditional way to extend templates.
     : include "foo.tx";
     : include "foo.tx" { var1 => value1, var2 => value2, ... };
 
+As C<cascade> does, C<include> allows barewords:
+
+    : include foo      # the same as 'foo.tx'
+    : include foo::bar # the same as 'foo/bar.tx'
+
 Xslate templates may be recursively included, but the including depth is
 limited to 100.
 
